==> moodle-1.8.14_20140504.zip: moodle/lang/en_utf8/countries.php <==
<?PHP // $Id: countries.php,v 1.2.4.2 2008/02/04 00:48:25 scyrma Exp $
      // countries.php - created with Moodle 1.7 beta + (2006101003)
      // http://www.iso.org/iso/country_codes/iso_3166_code_lists.htm
      //
      // UPDATE NOTE - When country codes are deleted or re-assigned, 
      // you must re-assign users to a valid country, doing both:
      // 1 - add an upgrade path in /lib/db/upgrade.php
      // 2 - add a line in the $country_update_map array, in 
      //     /backup/restorelib.php 

$string['AF'] = 'Afghanistan';
$string['AX'] = 'Åland Islands';
$string['AL'] = 'Albania';
$string['DZ'] = 'Algeria';
$string['AS'] = 'American Samoa';
$string['AD'] = 'Andorra';
$string['AO'] = 'Angola';
$string['AI'] = 'Anguilla';
$string['AQ'] = 'Antarctica';
$string['AG'] = 'Antigua And Barbuda';
$string['AR'] = 'Argentina';
$string['AM'] = 'Armenia';
$string['AW'] = 'Aruba';
$string['AU'] = 'Australia';
$string['AT'] = 'Austria';
$string['AZ'] = 'Azerbaijan';
$string['BS'] = 'Bahamas';
$string['BH'] = 'Bahrain';
$string['BD'] = 'Bangladesh';
$string['BB'] = 'Barbados';
$string['BY'] = 'Belarus';
$string['BE'] = 'Belgium';
$string['BZ'] = 'Belize';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BT'] = 'Bhutan';
$string['BO'] = 'Bolivia';
$string['BA'] = 'Bosnia And Herzegovina';
$string['BW'] = 'Botswana';
$string['BV'] = 'Bouvet Island';
$string['BR'] = 'Brazil';
$string['IO'] = 'British Indian Ocean Territory';
$string['BN'] = 'Brunei Darussalam';
$string['BG'] = 'Bulgaria';
$string['BF'] = 'Burkina Faso';
$string['BI'] = 'Burundi';
$string['KH'] = 'Cambodia';
$string['CM'] = 'Cameroon';
$string['CA'] = 'Canada';
$string['CV'] = 'Cape Verde';
$string['KY'] = 'Cayman Islands';
$string['CF'] = 'Central African Republic';
$string['TD'] = 'Chad';
$string['CL'] = 'Chile';
$string['CN'] = 'China';
$string['CX'] = 'Christmas Island';
$string['CC'] = 'Cocos (Keeling) Islands';
$string['CO'] = 'Colombia';
$string['KM'] = 'Comoros';
$string['CG'] = 'Congo';
$string['CD'] = 'Congo, The Democratic Republic Of The';
$string['CK'] = 'Cook Islands';
$string['CR'] = 'Costa Rica';
$string['CI'] = 'Côte D\'Ivoire';
$string['HR'] = 'Croatia';
$string['CU'] = 'Cuba';
$string['CY'] = 'Cyprus';
$string['CZ'] = 'Czech Republic';
$string['DK'] = 'Denmark';
$string['DJ'] = 'Djibouti';
$string['DM'] = 'Dominica';
$string['DO'] = 'Dominican Republic';
$string['EC'] = 'Ecuador';
$string['EG'] = 'Egypt';
$string['SV'] = 'El Salvador';
$string['GQ'] = 'Equatorial Guinea';
$string['ER'] = 'Eritrea';
$string['EE'] = 'Estonia';
$string['ET'] = 'Ethiopia';
$string['FK'] = 'Falkland Islands (Malvinas)';
$string['FO'] = 'Faroe Islands';
$string['FJ'] = 'Fiji';
$string['FI'] = 'Finland';
$string['FR'] = 'France';
$string['GF'] = 'French Guiana';
$string['PF'] = 'French Polynesia';
$string['TF'] = 'French Southern Territories';
$string['GA'] = 'Gabon';
$string['GM'] = 'Gambia';
$string['GE'] = 'Georgia';
$string['DE'] = 'Germany';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GR'] = 'Greece';
$string['GL'] = 'Greenland';
$string['GD'] = 'Grenada';
$string['GP'] = 'Guadeloupe';
$string['GU'] = 'Guam';
$string['GT'] = 'Guatemala';
$string['GG'] = 'Guernsey';
$string['GN'] = 'Guinea';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guyana';
$string['HT'] = 'Haiti';
$string['HM'] = 'Heard Island And Mcdonald Islands';
$string['VA'] = 'Holy See (Vatican City State)';
$string['HN'] = 'Honduras';
$string['HK'] = 'Hong Kong';
$string['HU'] = 'Hungary';
$string['IS'] = 'Iceland';
$string['IN'] = 'India';
$string['ID'] = 'Indonesia';
$string['IR'] = 'Iran, Islamic Republic Of';
$string['IQ'] = 'Iraq';
$string['IE'] = 'Ireland';
$string['IM'] = 'Isle Of Man';
$string['IL'] = 'Israel';
$string['IT'] = 'Italy';
$string['JM'] = 'Jamaica';
$string['JP'] = 'Japan';
$string['JE'] = 'Jersey';
$string['JO'] = 'Jordan';
$string['KZ'] = 'Kazakhstan';
$string['KE'] = 'Kenya';
$string['KI'] = 'Kiribati';
$string['KP'] = 'Korea, Democratic People\'S Republic Of';
$string['KR'] = 'Korea, Republic Of';
$string['KW'] = 'Kuwait';
$string['KG'] = 'Kyrgyzstan';
$string['LA'] = 'Lao People\'S Democratic Republic';
$string['LV'] = 'Latvia';
$string['LB'] = 'Lebanon';
$string['LS'] = 'Lesotho';
$string['LR'] = 'Liberia';
$string['LY'] = 'Libyan Arab Jamahiriya';
$string['LI'] = 'Liechtenstein';
$string['LT'] = 'Lithuania';
$string['LU'] = 'Luxembourg';
$string['MO'] = 'Macao';
$string['MK'] = 'Macedonia, The Former Yugoslav Republic Of';
$string['MG'] = 'Madagascar';
$string['MW'] = 'Malawi';
$string['MY'] = 'Malaysia';
$string['MV'] = 'Maldives';
$string['ML'] = 'Mali';
$string['MT'] = 'Malta';
$string['MH'] = 'Marshall Islands';
$string['MQ'] = 'Martinique';
$string['MR'] = 'Mauritania';
$string['MU'] = 'Mauritius';
$string['YT'] = 'Mayotte';
$string['MX'] = 'Mexico';
$string['FM'] = 'Micronesia, Federated States Of';
$string['MD'] = 'Moldova, Republic Of';
$string['MC'] = 'Monaco';
$string['MN'] = 'Mongolia';
$string['ME'] = 'Montenegro';
$string['MS'] = 'Montserrat';
$string['MA'] = 'Morocco';
$string['MZ'] = 'Mozambique';
$string['MM'] = 'Myanmar';
$string['NA'] = 'Namibia';
$string['NR'] = 'Nauru';
$string['NP'] = 'Nepal';
$string['NL'] = 'Netherlands';
$string['AN'] = 'Netherlands Antilles';
$string['NC'] = 'New Caledonia';
$string['NZ'] = 'New Zealand';
$string['NI'] = 'Nicaragua';
$string['NE'] = 'Niger';
$string['NG'] = 'Nigeria';
$string['NU'] = 'Niue';
$string['NF'] = 'Norfolk Island';
$string['MP'] = 'Northern Mariana Islands';
$string['NO'] = 'Norway';
$string['OM'] = 'Oman';
$string['PK'] = 'Pakistan';
$string['PW'] = 'Palau';
$string['PS'] = 'Palestinian Territory, Occupied';
$string['PA'] = 'Panama';
$string['PG'] = 'Papua New Guinea';
$string['PY'] = 'Paraguay';
$string['PE'] = 'Peru';
$string['PH'] = 'Philippines';
$string['PN'] = 'Pitcairn';
$string['PL'] = 'Poland';
$string['PT'] = 'Portugal';
$string['PR'] = 'Puerto Rico';
$string['QA'] = 'Qatar';
$string['RE'] = 'Réunion';
$string['RO'] = 'Romania';
$string['RU'] = 'Russian Federation';
$string['RW'] = 'Rwanda';
$string['BL'] = 'Saint Barthélemy';
$string['SH'] = 'Saint Helena';
$string['KN'] = 'Saint Kitts And Nevis';
$string['LC'] = 'Saint Lucia';
$string['MF'] = 'Saint Martin';
$string['PM'] = 'Saint Pierre And Miquelon';
$string['VC'] = 'Saint Vincent And The Grenadines';
$string['WS'] = 'Samoa';
$string['SM'] = 'San Marino';
$string['ST'] = 'Sao Tome And Principe';
$string['SA'] = 'Saudi Arabia';
$string['SN'] = 'Senegal';
$string['RS'] = 'Serbia';
$string['SC'] = 'Seychelles';
$string['SL'] = 'Sierra Leone';
$string['SG'] = 'Singapore';
$string['SK'] = 'Slovakia';
$string['SI'] = 'Slovenia';
$string['SB'] = 'Solomon Islands';
$string['SO'] = 'Somalia';
$string['ZA'] = 'South Africa';
$string['GS'] = 'South Georgia And The South Sandwich Islands';
$string['ES'] = 'Spain';
$string['LK'] = 'Sri Lanka';
$string['SD'] = 'Sudan';
$string['SR'] = 'Suriname';
$string['SJ'] = 'Svalbard And Jan Mayen';
$string['SZ'] = 'Swaziland';
$string['SE'] = 'Sweden';
$string['CH'] = 'Switzerland';
$string['SY'] = 'Syrian Arab Republic';
$string['TW'] = 'Taiwan, Province Of China';
$string['TJ'] = 'Tajikistan';
$string['TZ'] = 'Tanzania, United Republic Of';
$string['TH'] = 'Thailand';
$string['TL'] = 'Timor-Leste';
$string['TG'] = 'Togo';
$string['TK'] = 'Tokelau';
$string['TO'] = 'Tonga';
$string['TT'] = 'Trinidad And Tobago';
$string['TN'] = 'Tunisia';
$string['TR'] = 'Turkey';
$string['TM'] = 'Turkmenistan';
$string['TC'] = 'Turks And Caicos Islands';
$string['TV'] = 'Tuvalu';
$string['UG'] = 'Uganda';
$string['UA'] = 'Ukraine';
$string['AE'] = 'United Arab Emirates';
$string['GB'] = 'United Kingdom';
$string['US'] = 'United States';
$string['UM'] = 'United States Minor Outlying Islands';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VU'] = 'Vanuatu';
$string['VE'] = 'Venezuela';
$string['VN'] = 'Viet Nam';
$string['VG'] = 'Virgin Islands, British';
$string['VI'] = 'Virgin Islands, U.S.';
$string['WF'] = 'Wallis And Futuna';
$string['EH'] = 'Western Sahara';
$string['YE'] = 'Yemen';
$string['ZM'] = 'Zambia';
$string['ZW'] = 'Zimbabwe';

?>

==> moodle-1.9.19_20140504.zip: moodle/lang/en_utf8/countries.php <==
<?PHP // $Id$
      // countries.php - created with Moodle 1.7 beta + (2006101003)
      // http://www.iso.org/iso/country_codes/iso_3166_code_lists.htm
      //
      // UPDATE NOTE - When country codes are deleted or re-assigned, 
      // you must re-assign users to a valid country, doing both:
      // 1 - add an upgrade path in /lib/db/upgrade.php
      // 2 - add a line in the $country_update_map array, in 
      //     /backup/restorelib.php 

$string['AF'] = 'Afghanistan';
$string['AX'] = 'Åland Islands';
$string['AL'] = 'Albania';
$string['DZ'] = 'Algeria';
$string['AS'] = 'American Samoa';
$string['AD'] = 'Andorra';
$string['AO'] = 'Angola';
$string['AI'] = 'Anguilla';
$string['AQ'] = 'Antarctica';
$string['AG'] = 'Antigua And Barbuda';
$string['AR'] = 'Argentina';
$string['AM'] = 'Armenia';
$string['AW'] = 'Aruba';
$string['AU'] = 'Australia';
$string['AT'] = 'Austria';
$string['AZ'] = 'Azerbaijan';
$string['BS'] = 'Bahamas';
$string['BH'] = 'Bahrain';
$string['BD'] = 'Bangladesh';
$string['BB'] = 'Barbados';
$string['BY'] = 'Belarus';
$string['BE'] = 'Belgium';
$string['BZ'] = 'Belize';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BT'] = 'Bhutan';
$string['BO'] = 'Bolivia';
$string['BA'] = 'Bosnia And Herzegovina';
$string['BW'] = 'Botswana';
$string['BV'] = 'Bouvet Island';
$string['BR'] = 'Brazil';
$string['IO'] = 'British Indian Ocean Territory';
$string['BN'] = 'Brunei Darussalam';
$string['BG'] = 'Bulgaria';
$string['BF'] = 'Burkina Faso';
$string['BI'] = 'Burundi';
$string['KH'] = 'Cambodia';
$string['CM'] = 'Cameroon';
$string['CA'] = 'Canada';
$string['CV'] = 'Cape Verde';
$string['KY'] = 'Cayman Islands';
$string['CF'] = 'Central African Republic';
$string['TD'] = 'Chad';
$string['CL'] = 'Chile';
$string['CN'] = 'China';
$string['CX'] = 'Christmas Island';
$string['CC'] = 'Cocos (Keeling) Islands';
$string['CO'] = 'Colombia';
$string['KM'] = 'Comoros';
$string['CG'] = 'Congo';
$string['CD'] = 'Congo, The Democratic Republic Of The';
$string['CK'] = 'Cook Islands';
$string['CR'] = 'Costa Rica';
$string['CI'] = 'Côte D\'Ivoire';
$string['HR'] = 'Croatia';
$string['CU'] = 'Cuba';
$string['CY'] = 'Cyprus';
$string['CZ'] = 'Czech Republic';
$string['DK'] = 'Denmark';
$string['DJ'] = 'Djibouti';
$string['DM'] = 'Dominica';
$string['DO'] = 'Dominican Republic';
$string['EC'] = 'Ecuador';
$string['EG'] = 'Egypt';
$string['SV'] = 'El Salvador';
$string['GQ'] = 'Equatorial Guinea';
$string['ER'] = 'Eritrea';
$string['EE'] = 'Estonia';
$string['ET'] = 'Ethiopia';
$string['FK'] = 'Falkland Islands (Malvinas)';
$string['FO'] = 'Faroe Islands';
$string['FJ'] = 'Fiji';
$string['FI'] = 'Finland';
$string['FR'] = 'France';
$string['GF'] = 'French Guiana';
$string['PF'] = 'French Polynesia';
$string['TF'] = 'French Southern Territories';
$string['GA'] = 'Gabon';
$string['GM'] = 'Gambia';
$string['GE'] = 'Georgia';
$string['DE'] = 'Germany';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GR'] = 'Greece';
$string['GL'] = 'Greenland';
$string['GD'] = 'Grenada';
$string['GP'] = 'Guadeloupe';
$string['GU'] = 'Guam';
$string['GT'] = 'Guatemala';
$string['GG'] = 'Guernsey';
$string['GN'] = 'Guinea';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guyana';
$string['HT'] = 'Haiti';
$string['HM'] = 'Heard Island And Mcdonald Islands';
$string['VA'] = 'Holy See (Vatican City State)';
$string['HN'] = 'Honduras';
$string['HK'] = 'Hong Kong';
$string['HU'] = 'Hungary';
$string['IS'] = 'Iceland';
$string['IN'] = 'India';
$string['ID'] = 'Indonesia';
$string['IR'] = 'Iran, Islamic Republic Of';
$string['IQ'] = 'Iraq';
$string['IE'] = 'Ireland';
$string['IM'] = 'Isle Of Man';
$string['IL'] = 'Israel';
$string['IT'] = 'Italy';
$string['JM'] = 'Jamaica';
$string['JP'] = 'Japan';
$string['JE'] = 'Jersey';
$string['JO'] = 'Jordan';
$string['KZ'] = 'Kazakhstan';
$string['KE'] = 'Kenya';
$string['KI'] = 'Kiribati';
$string['KP'] = 'Korea, Democratic People\'s Republic Of';
$string['KR'] = 'Korea, Republic Of';
$string['KW'] = 'Kuwait';
$string['KG'] = 'Kyrgyzstan';
$string['LA'] = 'Lao People\'s Democratic Republic';
$string['LV'] = 'Latvia';
$string['LB'] = 'Lebanon';
$string['LS'] = 'Lesotho';
$string['LR'] = 'Liberia';
$string['LY'] = 'Libyan Arab Jamahiriya';
$string['LI'] = 'Liechtenstein';
$string['LT'] = 'Lithuania';
$string['LU'] = 'Luxembourg';
$string['MO'] = 'Macao';
$string['MK'] = 'Macedonia, The Former Yugoslav Republic Of';
$string['MG'] = 'Madagascar';
$string['MW'] = 'Malawi';
$string['MY'] = 'Malaysia';
$string['MV'] = 'Maldives';
$string['ML'] = 'Mali';
$string['MT'] = 'Malta';
$string['MH'] = 'Marshall Islands';
$string['MQ'] = 'Martinique';
$string['MR'] = 'Mauritania';
$string['MU'] = 'Mauritius';
$string['YT'] = 'Mayotte';
$string['MX'] = 'Mexico';
$string['FM'] = 'Micronesia, Federated States Of';
$string['MD'] = 'Moldova, Republic Of';
$string['MC'] = 'Monaco';
$string['MN'] = 'Mongolia';
$string['ME'] = 'Montenegro';
$string['MS'] = 'Montserrat';
$string['MA'] = 'Morocco';
$string['MZ'] = 'Mozambique';
$string['MM'] = 'Myanmar';
$string['NA'] = 'Namibia';
$string['NR'] = 'Nauru';
$string['NP'] = 'Nepal';
$string['NL'] = 'Netherlands';
$string['AN'] = 'Netherlands Antilles';
$string['NC'] = 'New Caledonia';
$string['NZ'] = 'New Zealand';
$string['NI'] = 'Nicaragua';
$string['NE'] = 'Niger';
$string['NG'] = 'Nigeria';
$string['NU'] = 'Niue';
$string['NF'] = 'Norfolk Island';
$string['MP'] = 'Northern Mariana Islands';
$string['NO'] = 'Norway';
$string['OM'] = 'Oman';
$string['PK'] = 'Pakistan';
$string['PW'] = 'Palau';
$string['PS'] = 'Palestinian Territory, Occupied';
$string['PA'] = 'Panama';
$string['PG'] = 'Papua New Guinea';
$string['PY'] = 'Paraguay';
$string['PE'] = 'Peru';
$string['PH'] = 'Philippines';
$string['PN'] = 'Pitcairn';
$string['PL'] = 'Poland';
$string['PT'] = 'Portugal';
$string['PR'] = 'Puerto Rico';
$string['QA'] = 'Qatar';
$string['RE'] = 'Réunion';
$string['RO'] = 'Romania';
$string['RU'] = 'Russian Federation';
$string['RW'] = 'Rwanda';
$string['BL'] = 'Saint Barthélemy';
$string['SH'] = 'Saint Helena';
$string['KN'] = 'Saint Kitts And Nevis';
$string['LC'] = 'Saint Lucia';
$string['MF'] = 'Saint Martin';
$string['PM'] = 'Saint Pierre And Miquelon';
$string['VC'] = 'Saint Vincent And The Grenadines';
$string['WS'] = 'Samoa';
$string['SM'] = 'San Marino';
$string['ST'] = 'Sao Tome And Principe';
$string['SA'] = 'Saudi Arabia';
$string['SN'] = 'Senegal';
$string['RS'] = 'Serbia';
$string['SC'] = 'Seychelles';
$string['SL'] = 'Sierra Leone';
$string['SG'] = 'Singapore';
$string['SK'] = 'Slovakia';
$string['SI'] = 'Slovenia';
$string['SB'] = 'Solomon Islands';
$string['SO'] = 'Somalia';
$string['ZA'] = 'South Africa';
$string['GS'] = 'South Georgia And The South Sandwich Islands';
$string['ES'] = 'Spain';
$string['LK'] = 'Sri Lanka';
$string['SD'] = 'Sudan';
$string['SR'] = 'Suriname';
$string['SJ'] = 'Svalbard And Jan Mayen';
$string['SZ'] = 'Swaziland';
$string['SE'] = 'Sweden';
$string['CH'] = 'Switzerland';
$string['SY'] = 'Syrian Arab Republic';
$string['TW'] = 'Taiwan';
$string['TJ'] = 'Tajikistan';
$string['TZ'] = 'Tanzania, United Republic Of';
$string['TH'] = 'Thailand';
$string['TL'] = 'Timor-Leste';
$string['TG'] = 'Togo';
$string['TK'] = 'Tokelau';
$string['TO'] = 'Tonga';
$string['TT'] = 'Trinidad And Tobago';
$string['TN'] = 'Tunisia';
$string['TR'] = 'Turkey';
$string['TM'] = 'Turkmenistan';
$string['TC'] = 'Turks And Caicos Islands';
$string['TV'] = 'Tuvalu';
$string['UG'] = 'Uganda';
$string['UA'] = 'Ukraine';
$string['AE'] = 'United Arab Emirates';
$string['GB'] = 'United Kingdom';
$string['US'] = 'United States';
$string['UM'] = 'United States Minor Outlying Islands';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VU'] = 'Vanuatu';
$string['VE'] = 'Venezuela';
$string['VN'] = 'Viet Nam';
$string['VG'] = 'Virgin Islands, British';
$string['VI'] = 'Virgin Islands, U.S.';
$string['WF'] = 'Wallis And Futuna';
$string['EH'] = 'Western Sahara';
$string['YE'] = 'Yemen';
$string['ZM'] = 'Zambia';
$string['ZW'] = 'Zimbabwe';

?>
